package com.persagy.apm.energy.report.monthly.outline.controller;

import com.persagy.apm.energy.report.monthly.outline.service.IReportOutlineService;

import org.springframework.beans.factory.annotation.Autowired;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.persagy.apm.energy.report.monthly.outline.model.*;
import com.persagy.apm.energy.report.monthly.outline.model.vo.*;
import com.persagy.apm.energy.report.monthly.outline.model.dto.*;
import com.persagy.apm.common.response.*;
import com.persagy.apm.common.utils.ResultHelper;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 报告表控制层
 *
 * @author lixing
 * @version V1.0 2021-05-17 10:47:26
 */
@Api(tags = "报告表")
@Validated
@RestController
@RequestMapping("reportOutlines")
public class ReportOutlineController {
    @Autowired
    private IReportOutlineService reportOutlineService;

    @ApiOperation(value = "创建报告表")
    @PostMapping("/create")
    public CommonResult<ApmResponseUpsertVO> createReportOutline(
            @Valid @RequestBody AddReportOutlineDTO addReportOutlineDTO) {
        String id = reportOutlineService.createReportOutline(addReportOutlineDTO);
        return ResultHelper.single(new ApmResponseUpsertVO(id));
    }

    @ApiOperation(value = "报告表详情")
    @PostMapping("/get")
    public CommonResult<ResponseReportOutlineItemVO> queryReportOutlineDetail(
            @Valid @RequestBody QueryReportOutlineDetailDTO queryReportOutlineDetailDTO) {
        ReportOutline reportOutline = reportOutlineService.queryReportOutlineDetail(queryReportOutlineDetailDTO.getId());
        ResponseReportOutlineItemVO responseReportOutlineItemVO = ConvertReportOutlineTool.INSTANCE.convert2ResponseItemDTO(reportOutline);
        return ResultHelper.single(responseReportOutlineItemVO);
    }


    @ApiOperation(value = "更新报告表")
    @PostMapping("/update")
    public CommonResult<ApmResponseUpsertVO> updateReportOutline(
            @Valid @RequestBody UpdateReportOutlineDTO updateReportOutlineDTO) {
        reportOutlineService.updateReportOutline(updateReportOutlineDTO);
        return ResultHelper.single(new ApmResponseUpsertVO(updateReportOutlineDTO.getId()));
    }


    @ApiOperation(value = "删除报告表")
    @PostMapping("/delete")
    public CommonResult deleteReportOutline(
            @RequestBody @Valid DeleteReportOutlineDTO deleteReportOutlineDTO) {
        reportOutlineService.deleteReportOutline(deleteReportOutlineDTO.getId());
        return ResultHelper.success();
    }


    @ApiOperation(value = "报告表列表")
    @PostMapping("/query")
    public CommonResult<PageList<ResponseReportOutlineListItemVO>> queryReportOutline(
            @Valid @RequestBody QueryReportOutlineDTO queryReportOutlineDTO) {
        List<ReportOutline> reportOutlineList = reportOutlineService.queryReportOutlineList(queryReportOutlineDTO);
        List<ResponseReportOutlineListItemVO> resultList = ConvertReportOutlineTool.INSTANCE.convert2List(reportOutlineList);
        return ResultHelper.multi(resultList);
    }

    //@ApiOperation(value = "报告表列表, 分页查询")
    //@PostMapping("/query")
    //public CommonResult<PageList<ResponseReportOutlineListItemVO>> queryReportOutline(
    //        @Valid @RequestBody PageQueryReportOutlineDTO pageQueryReportOutlineDTO) {
    //    IPage<ReportOutline> pagedList = reportOutlineService.pageQueryReportOutline(pageQueryReportOutlineDTO);
    //    IPage<ResponseReportOutlineListItemVO> pagedResultList = pagedList.convert(item -> {
    //        try {
    //           return ConvertReportOutlineTool.INSTANCE.convert2ResponseListItemDTO(item);
    //        } catch (Exception e) {
    //            throw new IllegalArgumentException("分页查询，ReportOutline实体类转换为列表对象发生异常", e);
    //        }
    //    });
    //    return ResultHelper.multi(pagedResultList);
    //}
}

